---
name: "\U0001F4D9 Documentation update"
about: Create a piece of documentation or update one that needs some care.
title: "[DOCS]"
labels: documentation
assignees: ""
---

## Which page or section is this issue related to?

<!-- Please include the URL and/or source. -->

## What are you documenting, or what change are you making in the documentation?

<!-- If a documentation needs to be created, please specify its coverage. -->
<!-- If there's a typo or something needs revisiting, please indicate it and show code/text/screenshots. -->
